@@ -16,7 +16,7 @@ SEXP weightedMean(SEXP x, SEXP w, SEXP idxs, SEXP naRm, SEXP refine) {
   R_xlen_t nx, nw;
 
   /* Argument 'x': */
-  assertArgVector(x, (R_TYPE_INT | R_TYPE_REAL), "x");
+  assertArgVector(x, (R_TYPE_LGL | R_TYPE_INT | R_TYPE_REAL), "x");
   nx = xlength(x);
 
   /* Argument 'x': */
@@ -34,14 +34,14 @@ SEXP weightedMean(SEXP x, SEXP w, SEXP idxs, SEXP naRm, SEXP refine) {
 
   /* Argument 'idxs': */
   R_xlen_t nidxs;
-  int idxsType;
-  void *cidxs = validateIndices(idxs, nx, 1, &nidxs, &idxsType);
+  int idxsHasNA;
+  R_xlen_t *cidxs = validateIndicesCheckNA(idxs, nx, 1, &nidxs, &idxsHasNA);
 
   /* Double matrices are more common to use. */
   if (isReal(x)) {
-    avg = weightedMean_dbl[idxsType](REAL(x), nx, REAL(w), cidxs, nidxs, narm, refine2);
-  } else if (isInteger(x)) {
-    avg = weightedMean_int[idxsType](INTEGER(x), nx, REAL(w), cidxs, nidxs, narm, refine2);
+    avg = weightedMean_dbl(REAL(x), nx, REAL(w), cidxs, nidxs, idxsHasNA, narm, refine2);
+  } else if (isInteger(x) | isLogical(x)) {
+    avg = weightedMean_int(INTEGER(x), nx, REAL(w), cidxs, nidxs, idxsHasNA, narm, refine2);
   }
 
   /* Return results */
