@@ -10,8 +10,7 @@ rowAlls_R <- function(x, value = TRUE, na.rm = FALSE, ..., useNames = NA) {
     dim <- dim(x) # for 0xN and Mx0 cases; needed in R (< 3.4.0)
     if (!isTRUE(all.equal(dim(y), dim))) {
       dim(y) <- dim
-      dimnames <- dimnames(x)
-      if (!is.null(dimnames)) dimnames(y) <- dimnames
+      dimnames(y) <- dimnames(x)
     }
     
     res <- apply(y, MARGIN = 1L, FUN = all, na.rm = na.rm)
@@ -30,8 +29,7 @@ rowAnys_R <- function(x, value = TRUE, na.rm = FALSE, ..., useNames = NA) {
     dim <- dim(x) # for 0xN and Mx0 cases; needed in R (< 3.4.0)
     if (!isTRUE(all.equal(dim(y), dim))) {
       dim(y) <- dim
-      dimnames <- dimnames(x)
-      if (!is.null(dimnames)) dimnames(y) <- dimnames
+      dimnames(y) <- dimnames(x)
     }
     
     res <- apply(y, MARGIN = 1L, FUN = any, na.rm = na.rm)
@@ -50,17 +48,17 @@ rowAnyMissings_R <- function(x, ..., useNames = NA) {
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 # Data type: logical
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-x <- matrix(FALSE, nrow = 20, ncol = 5)
-x[13:17, c(2, 4)] <- TRUE
-x[2:4, ] <- TRUE
+x <- matrix(FALSE, nrow = 10L, ncol = 4L)
+x[7:8, 2:3] <- TRUE
+x[1:3, ] <- TRUE
 x[, 1] <- TRUE
-x[5, ] <- FALSE
-x[, 5] <- FALSE
-x[3, ] <- FALSE
-x[4, ] <- TRUE
+x[4, ] <- FALSE
+x[, 4] <- FALSE
+x[2, ] <- FALSE
+x[3, ] <- TRUE
 
 # To check names attribute
-dimnames <- list(letters[1:20], LETTERS[1:5])
+dimnames <- list(letters[1:10], LETTERS[1:4])
 
 for (kk in 1:3) {
   if (kk == 2) {
@@ -72,30 +70,18 @@ for (kk in 1:3) {
 
   # Test with and without dimnames on x
   for (setDimnames in c(TRUE, FALSE)) {
-    if (setDimnames) dimnames(x) <- dimnames
-    else dimnames(x) <- NULL    
-    # Row/column all
+    dimnames(x) <- if (setDimnames) dimnames else NULL
+
     for (na.rm in c(FALSE, TRUE)) {
       # Check names attribute
-      for (useNames in c(NA, TRUE, FALSE)) {
+      for (useNames in c(if (!matrixStats:::isUseNamesNADefunct()) NA, TRUE, FALSE)) {
         m0 <- rowAlls_R(x, na.rm = na.rm, useNames = useNames)
         m1 <- rowAlls(x, na.rm = na.rm, useNames = useNames)
         m2 <- colAlls(t(x), na.rm = na.rm, useNames = useNames)
         str(list("all()", m0 = m0, m1 = m1, m2 = m2))
         stopifnot(identical(m1, m0))
         stopifnot(identical(m2, m0))        
-      }
-    }
-  }
-  
-  # Test with and without dimnames on x
-  for (setDimnames in c(TRUE, FALSE)) {
-    if (setDimnames) dimnames(x) <- dimnames
-    else dimnames(x) <- NULL    
-    # Row/column all
-    for (na.rm in c(FALSE, TRUE)) {
-      # Check names attribute
-      for (useNames in c(NA, TRUE, FALSE)) {
+
         m0 <- rowAnys_R(x, na.rm = na.rm, useNames = useNames)
         m1 <- rowAnys(x, na.rm = na.rm, useNames = useNames)
         m2 <- colAnys(t(x), na.rm = na.rm, useNames = useNames)
@@ -118,56 +104,50 @@ for (kk in 1:3) {
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 # Data type: integer
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-x <- matrix(rep(1:28, length.out = 10 * 5), nrow = 10, ncol = 5)
+x <- matrix(rep(1:6, length.out = 4 * 5), nrow = 4L, ncol = 5L)
 x[2, ] <- 7L
 x[3, 1] <- 7L
 x[2:3, 3:4] <- NA_integer_
 
 # To check names attribute
-dimnames <- list(letters[1:10], LETTERS[1:5])
+dimnames <- list(letters[1:4], LETTERS[1:5])
 
 # Row/column counts
 value <- 7L
-# Row/column all
-for (na.rm in c(FALSE, TRUE)) {
-  # Check names attribute
-  for (useNames in c(NA, TRUE, FALSE)) {
-    ## All
-    # Test with and without dimnames on x
-    for (setDimnames in c(TRUE, FALSE)) {
-      if (setDimnames) dimnames(x) <- dimnames
-      else dimnames(x) <- NULL 
+
+# Test with and without dimnames on x
+for (setDimnames in c(TRUE, FALSE)) {
+  dimnames(x) <- if (setDimnames) dimnames else NULL
+  for (na.rm in c(FALSE, TRUE)) {
+    # Check names attribute
+    for (useNames in c(if (!matrixStats:::isUseNamesNADefunct()) NA, TRUE, FALSE)) {
       r0 <- rowAlls_R(x, value = value, na.rm = na.rm, useNames = useNames)
       r1 <- rowAlls(x, value = value, na.rm = na.rm, useNames = useNames)
       r2 <- colAlls(t(x), value = value, na.rm = na.rm, useNames = useNames)
       stopifnot(identical(r1, r0))
       stopifnot(identical(r2, r1))
-    }
-    
-    for (rr in seq_len(nrow(x))) {
-      c <- allValue(x[rr, ], value = value, na.rm = na.rm)
-      stopifnot(identical(c, r1[rr]))
-      c <- allValue(x[rr, ], value = value, na.rm = na.rm)
-      stopifnot(identical(c, r1[rr]))
-    }
-    
-    ## Any
-    # Test with and without dimnames on x
-    for (setDimnames in c(TRUE, FALSE)) {
-      if (setDimnames) dimnames(x) <- dimnames
-      else dimnames(x) <- NULL
+      if (!is.na(useNames) && !useNames && !setDimnames) {
+        for (rr in seq_len(nrow(x))) {
+          c <- allValue(x[rr, ], value = value, na.rm = na.rm)
+          stopifnot(identical(c, r1[rr]))
+          c <- allValue(x[rr, ], value = value, na.rm = na.rm)
+          stopifnot(identical(c, r1[rr]))
+        }
+      }
+
       r0 <- rowAnys_R(x, value = value, na.rm = na.rm, useNames = useNames)
       r1 <- rowAnys(x, value = value, na.rm = na.rm, useNames = useNames)
       r2 <- colAnys(t(x), value = value, na.rm = na.rm, useNames = useNames)
       stopifnot(identical(r1, r0))
       stopifnot(identical(r2, r1))        
-    }
-    
-    for (rr in seq_len(nrow(x))) {
-      c <- anyValue(x[rr, ], value = value, na.rm = na.rm)
-      stopifnot(identical(c, r1[rr]))
-      c <- anyValue(x[rr, ], value = value, na.rm = na.rm)
-      stopifnot(identical(c, r1[rr]))
+      if (!is.na(useNames) && !useNames && !setDimnames) {
+        for (rr in seq_len(nrow(x))) {
+          c <- anyValue(x[rr, ], value = value, na.rm = na.rm)
+          stopifnot(identical(c, r1[rr]))
+          c <- anyValue(x[rr, ], value = value, na.rm = na.rm)
+          stopifnot(identical(c, r1[rr]))
+        }
+      }
     }
   }
 }
@@ -261,54 +241,49 @@ any_R <- function(x, value = TRUE, ...) {
   }
 }
 
-x <- matrix(rep(letters, length.out = 20 * 5), nrow = 20, ncol = 5)
+x <- matrix(rep(letters, length.out = 10 * 5), nrow = 10L, ncol = 5L)
 x[2, ] <- "g"
 x[2:4, 3:4] <- NA_character_
 
 # To check names attribute
-dimnames <- list(letters[1:20], LETTERS[1:5])
+dimnames <- list(letters[1:10], LETTERS[1:5])
 
-# Row/column counts
-for (value in c("g", NA_character_)) {
-  for (na.rm in c(FALSE, TRUE)) {
-    # Check names attribute
-    for (useNames in c(NA, TRUE, FALSE)) {
-      ## All
-      # Test with and without dimnames on x
-      for (setDimnames in c(TRUE, FALSE)) {
-        if (setDimnames) dimnames(x) <- dimnames
-        else dimnames(x) <- NULL 
+# Test with and without dimnames on x
+for (setDimnames in c(TRUE, FALSE)) {
+  dimnames(x) <- if (setDimnames) dimnames else NULL
+
+  # Row/column counts
+  for (value in c("g", NA_character_)) {
+    for (na.rm in c(FALSE, TRUE)) {
+      # Check names attribute
+      for (useNames in c(if (!matrixStats:::isUseNamesNADefunct()) NA, TRUE, FALSE)) {
         r0 <- rowAlls_R(x, value = value, na.rm = na.rm, useNames = useNames)
         r1 <- rowAlls(x, value = value, na.rm = na.rm, useNames = useNames)
         r2 <- colAlls(t(x), value = value, na.rm = na.rm, useNames = useNames)
         stopifnot(identical(r1, r0))
         stopifnot(identical(r2, r1))
-      }
-      
-      for (rr in seq_len(nrow(x))) {
-        c0 <- all_R(x[rr, ], value, na.rm = na.rm)
-        c <- allValue(x[rr, ], value = value, na.rm = na.rm)
-        stopifnot(identical(c, r1[rr]))
-        stopifnot(identical(c, c0))
-      }
-      
-      ## Any
-      # Test with and without dimnames on x
-      for (setDimnames in c(TRUE, FALSE)) {
-        if (setDimnames) dimnames(x) <- dimnames
-        else dimnames(x) <- NULL
+        if (!is.na(useNames) && !useNames && !setDimnames) {
+          for (rr in seq_len(nrow(x))) {
+            c0 <- all_R(x[rr, ], value, na.rm = na.rm)
+            c <- allValue(x[rr, ], value = value, na.rm = na.rm)
+            stopifnot(identical(c, r1[rr]))
+            stopifnot(identical(c, c0))
+          }
+        }
+        
         r0 <- rowAnys_R(x, value = value, na.rm = na.rm, useNames = useNames)
         r1 <- rowAnys(x, value = value, na.rm = na.rm, useNames = useNames)
         r2 <- colAnys(t(x), value = value, na.rm = na.rm, useNames = useNames)
         stopifnot(identical(r1, r0))
         stopifnot(identical(r2, r1))        
-      }
-      
-      for (rr in seq_len(nrow(x))) {
-        c0 <- any_R(x[rr, ], value, na.rm = na.rm)
-        c <- anyValue(x[rr, ], value = value, na.rm = na.rm)
-        stopifnot(identical(c, c0))
-        stopifnot(identical(c, r1[rr]))
+        if (!is.na(useNames) && !useNames && !setDimnames) {
+          for (rr in seq_len(nrow(x))) {
+            c0 <- any_R(x[rr, ], value, na.rm = na.rm)
+            c <- anyValue(x[rr, ], value = value, na.rm = na.rm)
+            stopifnot(identical(c, c0))
+            stopifnot(identical(c, r1[rr]))
+          }
+        }
       }
     }
   }
@@ -318,7 +293,7 @@ for (value in c("g", NA_character_)) {
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 # NA 0 test
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-x <- matrix(0, nrow = 3, ncol = 3)
+x <- matrix(0, nrow = 3L, ncol = 3L)
 x[1, ] <- c(NA_real_, NA_real_, 0)
 x[3, ] <- c(1, 0, 1)
 
@@ -326,10 +301,9 @@ dimnames <- list(letters[1:3], LETTERS[1:3])
 
 # Test with and without dimnames on x
 for (setDimnames in c(TRUE, FALSE)) {
-  if (setDimnames) dimnames(x) <- dimnames
-  else dimnames(x) <- NULL    
+  dimnames(x) <- if (setDimnames) dimnames else NULL
   # Check names attribute
-  for (useNames in c(NA, TRUE, FALSE)) {
+  for (useNames in c(if (!matrixStats:::isUseNamesNADefunct()) NA, TRUE, FALSE)) {
     r0 <- rowAnys_R(x, value = 0, useNames = useNames)
     r1 <- rowAnys(x, value = 0, useNames = useNames)
     stopifnot(identical(r0, r1))
